==> huaweicloudsdkcoc-3.1.138-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/count_multi_resources_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CountMultiResourcesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'data': 'list[ResourceMultiCountResponseData]'
    }

    attribute_map = {
        'data': 'data'
    }

    def __init__(self, data=None):
        """CountMultiResourcesResponse

        The model defined in huaweicloud sdk

        :param data: 云资源数量列表
        :type data: list[:class:`huaweicloudsdkcoc.v1.ResourceMultiCountResponseData`]
        """
        
        super(CountMultiResourcesResponse, self).__init__()

        self._data = None
        self.discriminator = None

        if data is not None:
            self.data = data

    @property
    def data(self):
        """Gets the data of this CountMultiResourcesResponse.

        云资源数量列表

        :return: The data of this CountMultiResourcesResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.ResourceMultiCountResponseData`]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this CountMultiResourcesResponse.

        云资源数量列表

        :param data: The data of this CountMultiResourcesResponse.
        :type data: list[:class:`huaweicloudsdkcoc.v1.ResourceMultiCountResponseData`]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CountMultiResourcesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.154-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/count_multi_resources_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CountMultiResourcesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'data': 'list[ResourceMultiCountResponseData]'
    }

    attribute_map = {
        'data': 'data'
    }

    def __init__(self, data=None):
        r"""CountMultiResourcesResponse

        The model defined in huaweicloud sdk

        :param data: 云资源数量列表
        :type data: list[:class:`huaweicloudsdkcoc.v1.ResourceMultiCountResponseData`]
        """
        
        super(CountMultiResourcesResponse, self).__init__()

        self._data = None
        self.discriminator = None

        if data is not None:
            self.data = data

    @property
    def data(self):
        r"""Gets the data of this CountMultiResourcesResponse.

        云资源数量列表

        :return: The data of this CountMultiResourcesResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.ResourceMultiCountResponseData`]
        """
        return self._data

    @data.setter
    def data(self, data):
        r"""Sets the data of this CountMultiResourcesResponse.

        云资源数量列表

        :param data: The data of this CountMultiResourcesResponse.
        :type data: list[:class:`huaweicloudsdkcoc.v1.ResourceMultiCountResponseData`]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CountMultiResourcesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
